@@ -5,6 +5,19 @@
 
 static const char* FILE_NAME = "Sys.c";
 
+int32_t SPVM__Sys__is_windows(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t defined = 0;
+  
+#   ifdef _WIN32
+  defined = 1;
+#   endif
+  
+  stack[0].ival = defined;
+  
+  return 0;
+}
+
 int32_t SPVM__Sys__defined(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t items = env->get_args_stack_length(env, stack);
@@ -279,7 +292,7 @@ int32_t SPVM__Sys__getenv(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__Sys__setenv(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "setenv is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -311,7 +324,7 @@ int32_t SPVM__Sys__setenv(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPVM__Sys__unsetenv(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "unsetenv is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
