@@ -22,6 +22,8 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
 =item L<Sys::Socket::Sockaddr::Interface|SPVM::Sys::Socket::Sockaddr::Interface>
 
+=item L<Cloneable|SPVM::Cloneable>
+
 =back
 
 =head1 Instance Methods
@@ -34,7 +36,7 @@ Retruns C<1>.
 
 =head2 sa_family
 
-  method sa_family : byte ()
+  method sa_family : int ()
 
 Gets C<sa_family>.
 
@@ -44,6 +46,12 @@ Gets C<sa_family>.
 
 The size of the structure internally used.
 
+=head2 clone
+
+  method clone : Sys::Socket::Sockaddr ();
+
+Clones this object.
+
 =head1 Well Known Child Classes
 
 =over 2
